#[non_exhaustive]pub enum OptimizeMode {
None,
Auto,
Lossless,
Lossy,
}Expand description
Optimization policy applied near the final encoding stage.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
None
Keep the current encoding behavior with no extra optimization work.
Auto
Pick the most appropriate optimization strategy for the target format.
Lossless
Only use lossless size-reduction techniques.
Lossy
Allow controlled quality loss for smaller output files.
Implementations